@@ -12,10 +12,10 @@ test_that(desc="pxweb_api_catalogue",{
   expect_silent(pxac <- pxweb_api_catalogue())
   expect_output(print(pxac), regexp = "Api:")
 
-  expect_silent(pxacgh <- pxweb:::pxweb_api_catalogue_from_github("test"))
+  expect_silent(pxacgh <- pxweb:::pxweb_api_catalogue_from_github("master"))
   expect_output(print(pxac), regexp = "Api:")
       
-  expect_equal(pxac[[1]], pxacgh[[1]])
+  expect_equal(pxac[[2]], pxacgh[[2]])
   
 })  
 
