@@ -6,7 +6,7 @@ test_that(desc="Access api paths",{
   # CRAN seem to run tests in parallel, hence API tests cannot be run on CRAN.
   skip_on_cran()
   
-  url <- "http://api.scb.se/OV0104/v1/doris/sv/ssd/START/AM/AM0301/"
+  url <- "https://api.scb.se/OV0104/v1/doris/sv/ssd/START/AM/AM0301/"
   expect_silent(scb <- pxweb(url))
 
   expect_equal(pxweb_api_name(scb), "api.scb.se")
