@@ -6,7 +6,7 @@ test_that(desc="Mixed node levels object",{
   # CRAN seem to run tests in parallel, hence API tests cannot be run on CRAN.
   skip_on_cran()
   
-  url <- "http://api.scb.se/OV0104/v1/doris/sv/ssd/START/AM/AM0301/"
+  url <- "https://api.scb.se/OV0104/v1/doris/sv/ssd/START/AM/AM0301/"
   expect_output(res <- suppressWarnings(pxweb_test_api(url)), regexp = "4 node.+and 14 table")
   expect_true(all(res$checked))
   # expect_true(all(!res$error)) # FIXME this also fails
@@ -18,6 +18,6 @@ test_that(desc="Mixed node levels object",{
   }
   
   expect_silent(api_paths <- pxweb:::pxweb_test_create_api_paths(apis = pxweb_api_catalogue()))
-  expect_true(all(c("http://api.scb.se/OV0104/v1/doris/en", 
-                    "http://api.scb.se/OV0104/v1/doris/sv") %in% api_paths$paths))
+  expect_true(all(c("https://api.scb.se/OV0104/v1/doris/en", 
+                    "https://api.scb.se/OV0104/v1/doris/sv") %in% api_paths$paths))
 })  
